@@ -8,10 +8,12 @@ __docformat__ = "restructuredtext en"
 
 from datetime import date
 
-from cubicweb.selectors import implements
+from logilab.common.date import ONEDAY, date_range
+
+from cubicweb.view import EntityAdapter
+from cubicweb.selectors import is_instance
 from cubicweb.web import uicfg
 from cubicweb.web.views import primary
-from cubicweb.web import uicfg
 
 uicfg.primaryview_section.tag_subject_of(('Task', 'todo_by', '*'), 'attributes')
 uicfg.primaryview_section.tag_subject_of(('Task', 'todo_by', '*'), 'sideboxes')
@@ -24,10 +26,11 @@ uicfg.actionbox_appearsin_addmenu.tag_object_of(('Task', 'depends_on', 'Task'),
 
 uicfg.autoform_field_kwargs.tag_attribute(
     ('Task', 'start'),
-    {'value': lambda form: form._cw.format_date(date.today())})
+    {'value': lambda form, field: form._cw.format_date(date.today())})
+
 
 class TaskPrimaryView(primary.PrimaryView):
-    __select__ = implements('Task')
+    __select__ = is_instance('Task')
 
     def render_entity_attributes(self, entity):
         self.w(u'<h2>%s - %s</h2>' % (self._cw.format_date(entity.start),
@@ -35,3 +38,21 @@ class TaskPrimaryView(primary.PrimaryView):
         super(TaskPrimaryView, self).render_entity_attributes(entity)
 
 
+class TaskICalendarViewsAdapter(EntityAdapter):
+    """calendar views interface"""
+    __regid__ = 'ICalendarViews'
+    __select__ = is_instance('Task')
+
+    def matching_dates(self, begin, end):
+        """calendar views interface"""
+        start = self.entity.start
+        stop = self.entity.stop
+        if not start and not stop:
+            return []
+        elif start and not stop:
+            stop = start
+        elif stop and not start:
+            start = stop
+        # date_range exclude the outer bound, hence + ONEDAY
+        return list(date_range(start, stop + ONEDAY))
+
